---
title: 'Philosophy'
description: 'The philosophy behind haolib'
icon: 'lightbulb'
---

<Warning>
This might be useless for you because this page is more of a set of postulates rather than a useful guide.
</Warning>


## The philosophy of haolib

- User Experience

- Customizability

- Meta-framework 

- Being SOTA 

- Implementation-agnosticism 

- 9/10

## Let's dive deeper into each postulate

### User Experience

- User Experience. It is probably the most important postulate since even if the library solves all the problems and it is not convenient to use, it is not haolib

- Customizability. If you cannot extend the library to your needs, it is not haolib

- Meta-framework. Another library which solves a similar problem using almost the same approach? It is not haolib

- Being SOTA. If your toolkit does not provide the best of the best, it is not haolib

- Implementation-agnosticism. If you cannot use the library without specific implementation, it is not haolib

- 9/10. If the library is not almost perfect, it is not haolib

### Wow, aren't you thinking too highly?

Well... If that's really what you think, you are probably right. But what is the motivation except being the best? 